@@ -133,22 +133,36 @@ mh_err_memory (int fatal)
 static char *my_name;
 static char *my_email;
 
-void
-mh_get_my_name (char *name)
+static char *
+mh_get_my_name (void)
 {
-  if (!name)
+  if (!my_name)
     {
       struct passwd *pw = getpwuid (getuid ());
       if (!pw)
 	{
 	  mu_error (_("cannot determine my username"));
-	  return;
+	  my_name = mu_strdup ("unknown");
 	}
-      name = pw->pw_name;
+      else
+	my_name = mu_strdup (pw->pw_name);
     }
+  return my_name;
+}
 
-  my_name = mu_strdup (name);
-  my_email = mu_get_user_email (name);
+char *
+mh_my_email (void)
+{
+  char *username = mh_get_my_name ();
+  if (!my_email)
+    {  
+      const char *p = mh_global_profile_get ("Local-Mailbox", NULL);
+      if (p)
+	my_email = mu_strdup (p);
+      else
+	my_email = mu_get_user_email (username);
+    }
+  return my_email;
 }
 
 int
@@ -176,9 +190,7 @@ mh_is_my_name (const char *name)
     for (p++; *p; p++)
       *p = mu_toupper (*p);
   
-  if (!my_email)
-    mh_get_my_name (NULL);
-  if (emailcmp (my_email, pname) == 0)
+  if (emailcmp (mh_my_email (), pname) == 0)
     rc = 1;
   else
     {
@@ -222,14 +234,6 @@ mh_is_my_name (const char *name)
   return rc;
 }
 
-char *
-mh_my_email ()
-{
-  if (!my_email)
-    mh_get_my_name (NULL);
-  return my_email;
-}
-
 static int
 make_dir_hier (const char *p, mode_t perm)
 {
@@ -856,11 +860,11 @@ mh_annotate (mu_message_t msg, const char *field, const char *text, int date)
       tm = localtime (&t);
       mu_strftime (datebuf, sizeof datebuf, "%a, %d %b %Y %H:%M:%S %Z", tm);
 
-      mu_header_set_value (hdr, field, datebuf, 0);
+      mu_header_prepend (hdr, field, datebuf);
     }
 
   if (text)
-    mu_header_set_value (hdr, field, text, 0);
+    mu_header_prepend (hdr, field, text);
   mu_message_get_attribute (msg, &attr);
   mu_attribute_set_modified (attr);
 }
@@ -1026,7 +1030,7 @@ mh_draft_message (const char *name, const char *msgspec, char **pname)
       if (!mh_msgset_single_message (msgset))
 	mu_error (_("only one message at a time!"));
       else
-	uid = mh_msgset_first_uid (msgset);
+	uid = mh_msgset_first (msgset, RET_UID);
       mu_msgset_free (msgset);
     }
 
