@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2005, 2006, 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005-2007, 2009-2012, 2014-2017 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,9 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <mh.h>
 
@@ -73,7 +72,7 @@ static int
 print_short (const char *str)
 {
   int n;
-  char *s;
+  const char *s;
   
   for (n = 0; *str; str++, n++)
     {
@@ -113,12 +112,12 @@ print_short (const char *str)
 }
 
 static void
-print_descr (int n, char *s)
+print_descr (int n, const char *s)
 {
   do
     {
-      char *p;
-      char *space = NULL;
+      const char *p;
+      const char *space = NULL;
       
       for (; n < OPT_DOC_COL; n++)
 	putchar (' ');
@@ -188,7 +187,6 @@ display_file (const char *name)
     {
       mu_stream_t stream;
       int rc;
-      size_t off = 0;
       size_t n;
       char buffer[512];
       
@@ -198,21 +196,15 @@ display_file (const char *name)
 	  mu_error ("mu_file_stream_create: %s", mu_strerror (rc));
 	  return;
 	}
-      rc = mu_stream_open (stream);
-      if (rc)
-	{
-	  mu_error ("mu_stream_open: %s", mu_strerror (rc));
-	  return;
-	} 
-      
-      while (mu_stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
+
+      mu_stream_seek (stream, 0, MU_SEEK_SET, NULL);
+      while (mu_stream_read (stream, buffer, sizeof buffer - 1, &n) == 0
 	     && n != 0)
 	{
 	  buffer[n] = '\0';
 	  printf ("%s", buffer);
-	  off += n;
 	}
-      mu_stream_destroy (&stream, NULL);
+      mu_stream_destroy (&stream);
     }
 }      
 
@@ -272,8 +264,8 @@ invoke (const char *compname, const char *defval, int argc, char **argv,
 
 struct anno_data
 {
-  char *field;
-  char *value;
+  const char *field;
+  const char *value;
   int date;
 };
 
@@ -307,16 +299,12 @@ annotate (struct mh_whatnow_env *wh)
 
       if (mu_address_get_nth (addr, i, &subaddr) == 0)
 	{
-	  size_t size;
 	  struct anno_data d;
 
-	  mu_address_to_string (subaddr, NULL, 0, &size);
-	  d.value = xmalloc (size + 1);
 	  d.field = wh->anno_field;
 	  d.date = i == 1;
-	  mu_address_to_string (subaddr, d.value, size + 1, NULL);
-	  mu_list_do (wh->anno_list, anno, &d);
-	  free (d.value);
+	  if (mu_address_sget_printable (subaddr, &d.value) == 0)
+	    mu_list_foreach (wh->anno_list, anno, &d);
 	  mu_address_destroy (&subaddr);
 	}
     }
@@ -331,35 +319,53 @@ static int
 _whatnow (struct mh_whatnow_env *wh, struct action_tab *tab)
 {
   int rc, status = 0;
+  char *line = NULL;
+  size_t size = 0;
+  struct mu_wordsplit ws;
+  int wsflags = MU_WRDSF_DEFFLAGS|MU_WRDSF_COMMENT;
+
+  wh->reedit = 0;
+  wh->last_ed = NULL;
   
   do
     {
-      char *line = NULL;
-      size_t size = 0;
-      int argc;
-      char **argv;
+      size_t n;
       handler_fp fun;
       
-      printf ("%s ", wh->prompt);
-      getline (&line, &size, stdin);
-      if (!line)
-	continue;
-      rc = mu_argcv_get (line, "", "#", &argc, &argv);
-      free (line);
+      mu_printf ("%s ", wh->prompt);
+      mu_stream_flush (mu_strout);
+      rc = mu_stream_getline (mu_strin, &line, &size, &n);
       if (rc)
 	{
-	  mu_argcv_free (argc, argv);
+	  mu_error (_("cannot read input stream: %s"), mu_strerror (rc));
+	  status = 1;
 	  break;
 	}
-
-      fun = func (tab, argv[0]);
+      if (n == 0)
+	break;
+      
+      ws.ws_comment = "#";
+      rc = mu_wordsplit (line, &ws, wsflags);
+      if (rc)
+	{
+	  mu_error (_("cannot split line `%s': %s"), line,
+		    mu_wordsplit_strerror (&ws));
+	  status = 1;
+	  break;
+	}
+      wsflags |= MU_WRDSF_REUSE;
+      fun = func (tab, ws.ws_wordv[0]);
       if (fun)
-	rc = fun (wh, argc, argv, &status);
+	rc = fun (wh, ws.ws_wordc, ws.ws_wordv, &status);
       else
 	rc = 0;
-      mu_argcv_free (argc, argv);
     }
   while (rc == 0);
+  if (wsflags & MU_WRDSF_REUSE)
+    mu_wordsplit_free (&ws);
+  free (wh->last_ed);
+  wh->last_ed = NULL;
+  free (line);
   return status;
 }
 
@@ -379,13 +385,87 @@ display (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 
 /* Edit action */
 static int
-edit (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
+edit (struct mh_whatnow_env *wh, int argc, char **argv, int *whs)
 {
-  char *name;
+  char const *ed = wh->last_ed ? wh->last_ed : wh->editor;
+  int i, rc, status;
+  char *p;
   
-  asprintf (&name, "%s-next", wh->editor);
-  invoke (name, wh->editor, argc, argv, wh->file, NULL);
-  free (name);
+  if (wh->reedit)
+    {
+      if (argc > 1)
+	ed = argv[1];
+      else
+	{
+	  char *name;
+	  char const *newed;
+	  mu_asprintf (&name, "%s-next", wh->editor);
+	  newed = mh_global_profile_get (name, NULL);
+	  free (name);
+	  if (newed)
+	    ed = newed;
+	}
+    }
+  else if (argc > 1)
+    ed = argv[1];
+
+  if (argc > 1)
+    {
+      char **xargv;
+
+      xargv = mu_calloc (argc+2, sizeof (*xargv));
+      xargv[0] = (char *)ed;
+      for (i = 1; i + 1 < argc; i++)
+	xargv[i] = argv[i+1];
+      xargv[i++] = wh->file;
+      xargv[i] = NULL;
+      rc = mu_spawnvp (xargv[0], xargv, &status);
+      free (xargv);
+    }
+  else
+    {      
+      struct mu_wordsplit ws;
+      extern char **environ;
+      ws.ws_env = (char const **)environ;
+      if (mu_wordsplit (ed, &ws,
+			MU_WRDSF_QUOTE
+			| MU_WRDSF_SQUEEZE_DELIMS
+			| MU_WRDSF_ENV 
+                        | MU_WRDSF_NOCMD))
+	{
+	  mu_error (_("cannot split line `%s': %s"), ed,
+		    mu_wordsplit_strerror (&ws));
+	  rc = MU_ERR_FAILURE;
+	}
+      else
+	{
+	  char *xargv[2];
+	  xargv[0] = wh->file;
+	  xargv[1] = NULL;
+	  if (mu_wordsplit_append (&ws, 1, xargv))
+	    {
+	      mu_error (_("cannot append arguments: %s"),
+			mu_wordsplit_strerror (&ws));
+	      rc = ENOMEM;
+	    }
+	  else
+	    rc = mu_spawnvp (ws.ws_wordv[0], ws.ws_wordv, &status);
+	  mu_wordsplit_free (&ws);
+	}
+    }
+      
+  if (rc || check_exit_status (ed, status))
+    {
+      if (wh->file)
+	mu_error (_("problems with edit--%s preserved"), wh->file);
+      else
+	mu_error (_("problems with edit"));
+    }
+
+  p = mu_strdup (ed);
+  free (wh->last_ed);
+  wh->last_ed = p;
+  wh->reedit = 1;
   
   return 0;
 }
@@ -422,12 +502,18 @@ quit (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 	unlink (wh->draftfile);
       else
 	{
-	  printf (_("draft left on \"%s\".\n"), wh->draftfile);
+	  mu_printf (_("draft left on \"%s\"."), wh->draftfile);
 	  if (strcmp (wh->file, wh->draftfile))
-	    rename (wh->file, wh->draftfile);
+	    {
+	      int rc;
+	      rc = mu_rename_file (wh->file, wh->draftfile, MU_COPY_OVERWRITE);
+	      if (rc)
+		mu_error (_("can't rename %s to %s: %s"),
+			  wh->file, wh->draftfile, mu_strerror (rc));
+	    }
 	}
     }
-
+  mu_printf ("\n");
   return 1;
 }
 
@@ -444,7 +530,10 @@ static int
 call_send (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
   if (invoke ("sendproc", MHBINDIR "/send", argc, argv, wh->file, NULL) == 0)
-    annotate (wh);
+    {
+      annotate (wh);
+      return 1;
+    }
   return 0;
 }
 
@@ -467,7 +556,7 @@ static struct helpdata whatnow_helptab[] = {
     N_("List the message being distributed/replied-to on the terminal.") },
   { "edit [<e <>]",
     N_("Edit the message. If EDITOR is omitted use the one that was used on"
-       " the preceeding round unless the profile entry \"LASTEDITOR-next\""
+       " the preceding round unless the profile entry \"LASTEDITOR-next\""
        " names an alternate editor.") },
   { "list [<>]",
     N_("List the draft on the terminal.") },
@@ -546,8 +635,8 @@ static struct action_tab whatnow_tab[] = {
   { NULL }
 };
 
-int
-mh_whatnow (struct mh_whatnow_env *wh, int initial_edit)
+static void
+set_default_editor (struct mh_whatnow_env *wh)
 {
   if (!wh->editor)
     {
@@ -557,16 +646,85 @@ mh_whatnow (struct mh_whatnow_env *wh, int initial_edit)
 					    p : (p = (getenv ("EDITOR"))) ?
 					          p : "prompter");	  
     }
+}
+
+int
+mh_whatnow (struct mh_whatnow_env *wh, int initial_edit)
+{
+  set_default_editor (wh);
   
-  if (initial_edit)
-    mh_spawnp (wh->editor, wh->file);
+  if (initial_edit && wh->file)
+    {
+      char *argv[2] = { "edit", NULL };
+      int status;
+      edit (wh, 1, argv, &status);
+    }
 
   if (!wh->prompt)
-    wh->prompt = _("What now?");
+    wh->prompt = (char*) _("What now?");
   
   return _whatnow (wh, whatnow_tab);
 }
 
+int
+mh_whatnowproc (struct mh_whatnow_env *wh, int initial_edit, const char *prog)
+{
+  int rc;
+  pid_t pid;
+
+  if (wh->nowhatnowproc)
+    return 0;
+  
+  if (!prog)
+    return mh_whatnow (wh, initial_edit);
+
+  pid = fork ();
+  if (pid == -1)
+    {
+      mu_diag_funcall (MU_DIAG_ERROR, "fork", NULL, errno);
+      return 1;
+    }
+  
+  if (pid == 0)
+    {
+      struct mu_wordsplit ws;
+      int i;
+      
+      if (mu_wordsplit (prog, &ws,
+			MU_WRDSF_DEFFLAGS & ~MU_WRDSF_CESCAPES))
+	{
+	  mu_error (_("cannot parse command line (%s): %s"), prog,
+		    mu_wordsplit_strerror (&ws));
+	  _exit (127);
+	}
+      
+      set_default_editor (wh);
+      mh_whatnow_env_to_environ (wh);
+      for (i = mu_getmaxfd (); i > 2; i--)
+	close (i);
+      execvp (ws.ws_wordv[0], ws.ws_wordv);
+      mu_diag_funcall (MU_DIAG_ERROR, "execvp", prog, errno);
+      _exit (127);
+    }
+
+  /* Master */
+  rc = 0;
+  while (1)
+    {
+      int status;
+      
+      if (waitpid (pid, &status, 0) == (pid_t)-1)
+	{
+	  if (errno == EINTR)
+	    continue;
+	  mu_diag_funcall (MU_DIAG_ERROR, "waitpid", prog, errno);
+	  rc = 1;
+	}
+      break;
+    }
+  return rc;
+}
+
 /* Disposition shell */
 static struct action_tab disp_tab[] = {
   { "help", disp_help },
@@ -585,8 +743,8 @@ mh_disposition (const char *filename)
   struct mh_whatnow_env wh;
   int rc;
   memset (&wh, 0, sizeof (wh));
-  wh.file = xstrdup (filename);
-  wh.prompt = _("Disposition?");
+  wh.file = mu_strdup (filename);
+  wh.prompt = (char*) _("Disposition?");
   rc = _whatnow (&wh, disp_tab);
   free (wh.file);
   return rc;
@@ -638,8 +796,8 @@ mh_usedraft (const char *filename)
   int rc;
   
   memset (&wh, 0, sizeof (wh));
-  wh.file = xstrdup (filename);
-  asprintf (&wh.prompt, _("Use \"%s\"?"), filename);
+  wh.file = mu_strdup (filename);
+  mu_asprintf (&wh.prompt, _("Use \"%s\"?"), filename);
   rc = _whatnow (&wh, usedraft_tab);
   free (wh.prompt);
   free (wh.file);
