@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 2.5.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.7"
+#define YYBISON_VERSION "2.5.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,15 +58,18 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
+/* Using locations.  */
+#define YYLSP_NEEDED 0
 
 
 
 /* Copy the first part of user declarations.  */
-/* Line 371 of yacc.c  */
+
+/* Line 268 of yacc.c  */
 #line 1 "pick.y"
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2007, 2009-2012, 2014-2016 Free Software
+   Copyright (C) 2003-2007, 2009-2012, 2014-2017 Free Software
    Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -104,8 +107,9 @@ static node_t *parse_tree;
 static int nesting_level;
 static int reg_flags = REG_EXTENDED|REG_ICASE;
 
-/* Line 371 of yacc.c  */
-#line 109 "pick-gram.c"
+
+/* Line 268 of yacc.c  */
+#line 113 "pick-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -115,6 +119,11 @@ static int reg_flags = REG_EXTENDED|REG_ICASE;
 #  endif
 # endif
 
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -123,18 +132,12 @@ static int reg_flags = REG_EXTENDED|REG_ICASE;
 # define YYERROR_VERBOSE 0
 #endif
 
-/* In a future release of Bison, this section will be replaced
-   by #include "y.tab.h".  */
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-#if YYDEBUG
-extern int pick_yydebug;
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
 #endif
 
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -169,10 +172,12 @@ extern int pick_yydebug;
 
 
 
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 387 of yacc.c  */
+
+/* Line 295 of yacc.c  */
 #line 48 "pick.y"
 
   char *string;
@@ -180,36 +185,21 @@ typedef union YYSTYPE
   regex_t regex;
 
 
-/* Line 387 of yacc.c  */
-#line 185 "pick-gram.c"
+
+/* Line 295 of yacc.c  */
+#line 191 "pick-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define pick_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
-extern YYSTYPE pick_yylval;
-
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int pick_yyparse (void *YYPARSE_PARAM);
-#else
-int pick_yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int pick_yyparse (void);
-#else
-int pick_yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
-
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-/* Line 390 of yacc.c  */
-#line 213 "pick-gram.c"
+
+/* Line 345 of yacc.c  */
+#line 203 "pick-gram.c"
 
 #ifdef short
 # undef short
@@ -262,24 +252,24 @@ typedef short int pick_yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
+#   define YY_(msgid) dgettext ("bison-runtime", msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(Msgid) Msgid
+#  define YY_(msgid) msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(E) ((void) (E))
+# define YYUSE(e) ((void) (e))
 #else
-# define YYUSE(E) /* empty */
+# define YYUSE(e) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(N) (N)
+# define YYID(n) (n)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -506,7 +496,7 @@ static const pick_yytype_uint8 pick_yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const pick_yytname[] =
@@ -587,10 +577,10 @@ static const pick_yytype_int8 pick_yytable[] =
       23,     0,     6,    20,    21,    24
 };
 
-#define pick_yypact_value_is_default(Yystate) \
-  (!!((Yystate) == (-7)))
+#define pick_yypact_value_is_default(pick_yystate) \
+  ((pick_yystate) == (-7))
 
-#define pick_yytable_value_is_error(Yytable_value) \
+#define pick_yytable_value_is_error(pick_yytable_value) \
   YYID (0)
 
 static const pick_yytype_int8 pick_yycheck[] =
@@ -655,18 +645,46 @@ do                                                              \
     }								\
 while (YYID (0))
 
-/* Error token number */
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+#ifndef YYLLOC_DEFAULT
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (YYID (N))                                                    \
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (YYID (0))
+#endif
+
+
 /* This macro is provided for backward compatibility. */
+
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `pick_yylex' with the right arguments.  */
+
 #ifdef YYLEX_PARAM
 # define YYLEX pick_yylex (YYLEX_PARAM)
 #else
@@ -729,7 +747,7 @@ pick_yy_symbol_value_print (pick_yyoutput, pick_yytype, pick_yyvaluep)
   switch (pick_yytype)
     {
       default:
-        break;
+	break;
     }
 }
 
@@ -971,6 +989,7 @@ pick_yysyntax_error (YYSIZE_T *pick_yymsg_alloc, char **pick_yymsg,
 {
   YYSIZE_T pick_yysize0 = pick_yytnamerr (YY_NULL, pick_yytname[pick_yytoken]);
   YYSIZE_T pick_yysize = pick_yysize0;
+  YYSIZE_T pick_yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *pick_yyformat = YY_NULL;
@@ -1033,13 +1052,11 @@ pick_yysyntax_error (YYSIZE_T *pick_yymsg_alloc, char **pick_yymsg,
                     break;
                   }
                 pick_yyarg[pick_yycount++] = pick_yytname[pick_yyx];
-                {
-                  YYSIZE_T pick_yysize1 = pick_yysize + pick_yytnamerr (YY_NULL, pick_yytname[pick_yyx]);
-                  if (! (pick_yysize <= pick_yysize1
-                         && pick_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                    return 2;
-                  pick_yysize = pick_yysize1;
-                }
+                pick_yysize1 = pick_yysize + pick_yytnamerr (YY_NULL, pick_yytname[pick_yyx]);
+                if (! (pick_yysize <= pick_yysize1
+                       && pick_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  return 2;
+                pick_yysize = pick_yysize1;
               }
         }
     }
@@ -1059,12 +1076,10 @@ pick_yysyntax_error (YYSIZE_T *pick_yymsg_alloc, char **pick_yymsg,
 # undef YYCASE_
     }
 
-  {
-    YYSIZE_T pick_yysize1 = pick_yysize + pick_yystrlen (pick_yyformat);
-    if (! (pick_yysize <= pick_yysize1 && pick_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-      return 2;
-    pick_yysize = pick_yysize1;
-  }
+  pick_yysize1 = pick_yysize + pick_yystrlen (pick_yyformat);
+  if (! (pick_yysize <= pick_yysize1 && pick_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    return 2;
+  pick_yysize = pick_yysize1;
 
   if (*pick_yymsg_alloc < pick_yysize)
     {
@@ -1124,27 +1139,32 @@ pick_yydestruct (pick_yymsg, pick_yytype, pick_yyvaluep)
     {
 
       default:
-        break;
+	break;
     }
 }
 
 
+/* Prevent warnings from -Wmissing-prototypes.  */
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int pick_yyparse (void *YYPARSE_PARAM);
+#else
+int pick_yyparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int pick_yyparse (void);
+#else
+int pick_yyparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int pick_yychar;
 
-
-#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-# define YY_IGNORE_MAYBE_UNINITIALIZED_END
-#endif
-#ifndef YY_INITIAL_VALUE
-# define YY_INITIAL_VALUE(Value) /* Nothing. */
-#endif
-
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE pick_yylval YY_INITIAL_VALUE(pick_yyval_default);
+YYSTYPE pick_yylval;
 
 /* Number of syntax errors so far.  */
 int pick_yynerrs;
@@ -1202,7 +1222,7 @@ pick_yyparse ()
   int pick_yyn;
   int pick_yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int pick_yytoken = 0;
+  int pick_yytoken;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE pick_yyval;
@@ -1220,8 +1240,9 @@ pick_yyparse ()
      Keep to zero when no symbol should be popped.  */
   int pick_yylen = 0;
 
-  pick_yyssp = pick_yyss = pick_yyssa;
-  pick_yyvsp = pick_yyvs = pick_yyvsa;
+  pick_yytoken = 0;
+  pick_yyss = pick_yyssa;
+  pick_yyvs = pick_yyvsa;
   pick_yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1230,6 +1251,14 @@ pick_yyparse ()
   pick_yyerrstatus = 0;
   pick_yynerrs = 0;
   pick_yychar = YYEMPTY; /* Cause a token to be read.  */
+
+  /* Initialize stack pointers.
+     Waste one element of value and location stack
+     so that they stay on the same level as the state stack.
+     The wasted elements are never initialized.  */
+  pick_yyssp = pick_yyss;
+  pick_yyvsp = pick_yyvs;
+
   goto pick_yysetstate;
 
 /*------------------------------------------------------------.
@@ -1370,9 +1399,7 @@ pick_yybackup:
   pick_yychar = YYEMPTY;
 
   pick_yystate = pick_yyn;
-  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++pick_yyvsp = pick_yylval;
-  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto pick_yynewstate;
 
@@ -1409,7 +1436,8 @@ pick_yyreduce:
   switch (pick_yyn)
     {
         case 2:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 60 "pick.y"
     {
 	     parse_tree = NULL;
@@ -1417,7 +1445,8 @@ pick_yyreduce:
     break;
 
   case 3:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 64 "pick.y"
     {
 	     parse_tree = (pick_yyvsp[(1) - (1)].node);
@@ -1425,7 +1454,8 @@ pick_yyreduce:
     break;
 
   case 5:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 71 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_and, (pick_yyvsp[(1) - (2)].node), (pick_yyvsp[(2) - (2)].node));
@@ -1433,7 +1463,8 @@ pick_yyreduce:
     break;
 
   case 7:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 78 "pick.y"
     {
 	     set_cflags ((pick_yyvsp[(1) - (1)].string));
@@ -1441,7 +1472,8 @@ pick_yyreduce:
     break;
 
   case 8:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 84 "pick.y"
     {
 	     int rc = regcomp (&(pick_yyval.regex), (pick_yyvsp[(2) - (2)].string), reg_flags|REG_NOSUB);
@@ -1457,7 +1489,8 @@ pick_yyreduce:
     break;
 
   case 9:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 98 "pick.y"
     {
 	     (pick_yyval.node) = (pick_yyvsp[(2) - (3)].node);
@@ -1465,7 +1498,8 @@ pick_yyreduce:
     break;
 
   case 10:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 102 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_regex, (pick_yyvsp[(2) - (3)].string), regex_dup (&(pick_yyvsp[(3) - (3)].regex)));
@@ -1473,7 +1507,8 @@ pick_yyreduce:
     break;
 
   case 11:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 106 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_regex, NULL, regex_dup (&(pick_yyvsp[(1) - (1)].regex)));
@@ -1481,7 +1516,8 @@ pick_yyreduce:
     break;
 
   case 12:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 110 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_datefield, (pick_yyvsp[(1) - (1)].string), NULL);
@@ -1489,7 +1525,8 @@ pick_yyreduce:
     break;
 
   case 13:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 114 "pick.y"
     {
 	     time_t t;
@@ -1504,7 +1541,8 @@ pick_yyreduce:
     break;
 
   case 14:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 125 "pick.y"
     {
 	     time_t t;
@@ -1519,7 +1557,8 @@ pick_yyreduce:
     break;
 
   case 15:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 136 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_and, (pick_yyvsp[(1) - (3)].node), (pick_yyvsp[(3) - (3)].node));
@@ -1527,7 +1566,8 @@ pick_yyreduce:
     break;
 
   case 16:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 140 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_or, (pick_yyvsp[(1) - (3)].node), (pick_yyvsp[(3) - (3)].node));
@@ -1535,7 +1575,8 @@ pick_yyreduce:
     break;
 
   case 17:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 144 "pick.y"
     {
 	     (pick_yyval.node) = pick_node_create (node_not, (pick_yyvsp[(2) - (2)].node), NULL);
@@ -1543,7 +1584,8 @@ pick_yyreduce:
     break;
 
   case 18:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 150 "pick.y"
     {
 	     nesting_level++;
@@ -1551,7 +1593,8 @@ pick_yyreduce:
     break;
 
   case 19:
-/* Line 1792 of yacc.c  */
+
+/* Line 1810 of yacc.c  */
 #line 156 "pick.y"
     {
 	     nesting_level--;
@@ -1559,8 +1602,9 @@ pick_yyreduce:
     break;
 
 
-/* Line 1792 of yacc.c  */
-#line 1564 "pick-gram.c"
+
+/* Line 1810 of yacc.c  */
+#line 1608 "pick-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter pick_yychar, and that requires
@@ -1723,9 +1767,7 @@ pick_yyerrlab1:
       YY_STACK_PRINT (pick_yyss, pick_yyssp);
     }
 
-  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++pick_yyvsp = pick_yylval;
-  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
@@ -1791,7 +1833,8 @@ pick_yyreturn:
 }
 
 
-/* Line 2055 of yacc.c  */
+
+/* Line 2071 of yacc.c  */
 #line 161 "pick.y"
 
 
@@ -2078,3 +2121,4 @@ set_cflags (char const *str)
 	}
     }
 }
+
